# $Header: /usr/local/CVS/Perl-Metrics-Simple/Build.PL,v 1.10 2006/11/26 06:47:43 matisse Exp $
# $Revision: 1.10 $
# $Author: matisse $
# $Source: /usr/local/CVS/Perl-Metrics-Simple/Build.PL,v $
# $Date: 2006/11/26 06:47:43 $
###############################################################################

use Module::Build;

# See perldoc Module::Build for details of how this works

Module::Build->new(
    module_name => 'Perl::Metrics::Simple',
    license     => 'perl',
    requires    => {
        'Readonly'            => 1.03,
        'PPI'                 => 1.113,
        'Statistics::Basic'   => 0.42,
        'Pod::Usage'          => 0,
    },
    build_requires => {
        'Module::Build' => 0.2612,
	'Test::Pod' => 1.00,
	'Test::Pod::Coverage' => 1.04,
    },
    script_files   => { 'bin/countperl' => 1, },
    add_to_cleanup => [ '*.tar.gz', ],
)->create_build_script;
